<?xml version="1.0" encoding="utf-8"?><!DOCTYPE TS><TS language="uk" sourcelanguage="en" version="2.0">
<context>
    <name>AboutDialogBase</name>
    <message>
        <location filename="res/AboutDialogBase.ui" line="38"/>
        <source>About Barrier</source>
        <translation type="finished">Про Barrier</translation>
    </message>
    <message utf8="true">
        <location filename="res/AboutDialogBase.ui" line="53"/>
        <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="140"/>
        <source>Unknown</source>
        <translation type="finished">Невідомо</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="124"/>
        <source>Version:</source>
        <translation type="finished">Версія:</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="163"/>
        <source>&amp;Ok</source>
        <translation type="finished">OK</translation>
    </message>
</context>
<context>
    <name>ActionDialogBase</name>
    <message>
        <location filename="res/ActionDialogBase.ui" line="14"/>
        <source>Configure Action</source>
        <translation type="finished">Налаштування дій</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="20"/>
        <source>Choose the action to perform</source>
        <translation type="finished">Виберіть дію, що виконується</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="26"/>
        <source>Press a hotkey</source>
        <translation type="finished">Натисніть гарячу клавішу</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="36"/>
        <source>Release a hotkey</source>
        <translation type="finished">Відпустіть гарячу клавішу</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="43"/>
        <source>Press and release a hotkey</source>
        <translation type="finished">Натисніть та відпустіть гарячу клавішу</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="69"/>
        <source>only on these screens</source>
        <translation type="finished">тільки на цих екранах</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="119"/>
        <source>Switch to screen</source>
        <translation type="finished">Перехід на екран</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="150"/>
        <source>Switch in direction</source>
        <translation type="finished">Перехід в напрямку</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="174"/>
        <source>left</source>
        <translation type="finished">вліво</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="179"/>
        <source>right</source>
        <translation type="finished">вправо</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="184"/>
        <source>up</source>
        <translation type="finished">вверх</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="189"/>
        <source>down</source>
        <translation type="finished">вниз</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="201"/>
        <source>Lock cursor to screen</source>
        <translation type="finished">Закріпити курсор за екраном</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="225"/>
        <source>toggle</source>
        <translation type="finished">переключити</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="230"/>
        <source>on</source>
        <translation type="finished">ввімк.</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="235"/>
        <source>off</source>
        <translation type="finished">вимк.</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="248"/>
        <source>This action is performed when</source>
        <translation type="finished">Ця дія виконується коли</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="254"/>
        <source>the hotkey is pressed</source>
        <translation type="finished">гаряча клавіша натиснута</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="264"/>
        <source>the hotkey is released</source>
        <translation type="finished">гаряча клавіша відпущена</translation>
    </message>
</context>
<context>
    <name>AddClientDialog</name>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="20"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="35"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="83"/>
        <source>Ignore auto connect clients</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotkeyDialogBase</name>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="14"/>
        <source>Hotkey</source>
        <translation type="finished">Гаряча клавіша</translation>
    </message>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="20"/>
        <source>Enter the specification for the hotkey:</source>
        <translation type="finished">Вкажіть специфікацію гарячої клавіші:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="790"/>
        <source>&amp;Start</source>
        <translation type="finished">Старт</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>&amp;File</source>
        <translation type="finished">Файл</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="238"/>
        <source>&amp;Edit</source>
        <translation type="finished">Редагування</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="239"/>
        <source>&amp;Window</source>
        <translation type="finished">Вікно</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="240"/>
        <source>&amp;Help</source>
        <translation type="finished">Допомога</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="364"/>
        <source>&lt;p&gt;Your version of Barrier is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
        <translation type="finished">&lt;p&gt;Ваша версія Barrier застаріла. Зараз доступна версія &lt;b&gt;%1&lt;/b&gt; для &lt;a href=&quot;%2&quot;&gt;завантаження&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>Program can not be started</source>
        <translation type="finished">Програма не може бути запущена</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
        <translation type="finished">Виконуваний фал &lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;не може запуститись, хоча він існує. Будь ласка, перевірте чи у Вас достатньо прав для запуску цієї програми.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="596"/>
        <source>Barrier client not found</source>
        <translation type="finished">Не знайдено жодного клієнта Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="597"/>
        <source>The executable for the barrier client does not exist.</source>
        <translation type="finished">Виконуваної програми для клієнта Barrier не існує.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="625"/>
        <source>Hostname is empty</source>
        <translation type="finished">Ім'я хосту не вказане</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="626"/>
        <source>Please fill in a hostname for the barrier client to connect to.</source>
        <translation type="finished">Будь ласка вкажіть ім'я хосту до якого повинен приєднатися клієнт Barrier.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>Cannot write configuration file</source>
        <translation type="finished">Неможливо здійснити запис у файл конфігурації</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>The temporary configuration file required to start barrier can not be written.</source>
        <translation type="finished">Тимчасовий файл конфігурації, який необхідний для запуску Barrier заблокований для запису.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="659"/>
        <source>Configuration filename invalid</source>
        <translation type="finished">Неправильне ім'я файлу конфігурації</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="660"/>
        <source>You have not filled in a valid configuration file for the barrier server. Do you want to browse for the configuration file now?</source>
        <translation type="finished">Ви не заповнили правильний файл конфігурації для сервера Barrier . Бажаєте зробити це зараз?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="688"/>
        <source>Barrier server not found</source>
        <translation type="finished">Неможливо знайти сервер Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="689"/>
        <source>The executable for the barrier server does not exist.</source>
        <translation type="finished">Виконуваної програми для серверу Barrier не існує.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated with an error</source>
        <translation type="finished">Barrier завершена з помилками</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated unexpectedly with an exit code of %1.&lt;br&gt;&lt;br&gt;Please see the log output for details.</source>
        <translation type="finished">Barrier завершилась неочікувано з кодом of %1.&lt;br&gt;&lt;br&gt;Будь ласка перегляньте log-записи для деталей.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="783"/>
        <source>&amp;Stop</source>
        <translation type="finished">Стоп</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1038"/>
        <source>Please add the server (%1) to the grid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1044"/>
        <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1147"/>
        <source>Failed to detect system architecture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1189"/>
        <source>Failed to download Bonjour installer to location: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1226"/>
        <source>Do you want to enable auto config and install Bonjour?

This feature helps you establish the connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1270"/>
        <source>Auto config feature requires Bonjour.

Do you want to install Bonjour?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="815"/>
        <source>Barrier is starting.</source>
        <translation type="finished">Barrier запущено.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="809"/>
        <source>Barrier is running.</source>
        <translation type="finished">Barrier працює.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="819"/>
        <source>Barrier is not running.</source>
        <translation type="finished">Barrier зупинено.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="870"/>
        <source>Unknown</source>
        <translation type="finished">Невідомо</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1146"/>
        <location filename="src/MainWindow.cpp" line="1225"/>
        <location filename="src/MainWindow.cpp" line="1269"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="987"/>
        <source>Browse for a barriers config file</source>
        <translation type="finished">Вкажіть файл конфігурації Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>Barrier is now connected, You can close the config window. Barrier will remain connected in the background.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="434"/>
        <source>Security question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="435"/>
        <source>Do you trust this fingerprint?

%1

This is a server fingerprint. You should compare this fingerprint to the one on your server's screen. If the two don't match exactly, then it's probably not the server you're expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1000"/>
        <source>Save configuration as...</source>
        <translation type="finished">Зберегти конфігурацію як...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Save failed</source>
        <translation type="finished">Посилка збереження</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Could not save configuration to file.</source>
        <translation type="finished">Неможливо зберегти файл конфігурації.</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <location filename="res/MainWindowBase.ui" line="26"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="90"/>
        <source>Ser&amp;ver (share this computer's mouse and keyboard):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="243"/>
        <source>Screen name:</source>
        <translation type="finished">Ім'я екрану:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="257"/>
        <source>&amp;Server IP:</source>
        <translation type="finished">IP серверу:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="380"/>
        <location filename="res/MainWindowBase.ui" line="409"/>
        <source>&amp;Start</source>
        <translation type="finished">Старт</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="181"/>
        <source>Use existing configuration:</source>
        <translation type="finished">Використати існуючу конфігурацію:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="190"/>
        <source>&amp;Configuration file:</source>
        <translation type="finished">Файл конфігурації:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="210"/>
        <source>&amp;Browse...</source>
        <translation type="finished">Перегляд...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="147"/>
        <source>Configure interactively:</source>
        <translation type="finished">Налаштувати інтерактивно:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="159"/>
        <source>&amp;Configure Server...</source>
        <translation type="finished">Налаштувати сервер...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="350"/>
        <source>Ready</source>
        <translation type="finished">Готово</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="296"/>
        <source>Log</source>
        <translation type="finished">Лог</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="373"/>
        <source>&amp;Reload</source>
        <translation type="finished">Застосувати</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="107"/>
        <source>IP addresses:</source>
        <translation type="finished">IP адреси:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="131"/>
        <source>Fingerprint:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="228"/>
        <source>&amp;Client (use another computer's mouse and keyboard):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="270"/>
        <source>Auto config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="390"/>
        <source>&amp;About Barrier...</source>
        <translation type="finished">Про Barrier</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="398"/>
        <source>&amp;Quit</source>
        <translation type="finished">Закрити</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="401"/>
        <source>Quit</source>
        <translation type="finished">Закрити</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="412"/>
        <source>Run</source>
        <translation type="finished">Запустити</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="423"/>
        <source>S&amp;top</source>
        <translation type="finished">Зупинити</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="426"/>
        <source>Stop</source>
        <translation type="finished">Зупинити</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="434"/>
        <source>S&amp;how Status</source>
        <translation type="finished">Показати статус</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="442"/>
        <source>&amp;Hide</source>
        <translation type="finished">Приховати</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="445"/>
        <source>Hide</source>
        <translation type="finished">Приховати</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="453"/>
        <source>&amp;Show</source>
        <translation type="finished">Показати</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="456"/>
        <source>Show</source>
        <translation type="finished">Показати</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="464"/>
        <source>Save configuration &amp;as...</source>
        <translation type="finished">Зберегти конфігурацію як...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="467"/>
        <source>Save the interactively generated server configuration to a file.</source>
        <translation type="finished">Зберегти інтерактивно згенеровану конфігурацію сервера у файл.</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="475"/>
        <source>Settings</source>
        <translation type="finished">Налаштування</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="478"/>
        <source>Edit settings</source>
        <translation type="finished">Редагувати налаштування</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="486"/>
        <source>Run Wizard</source>
        <translation type="finished">Запустити Помічника</translation>
    </message>
</context>
<context>
    <name>NewScreenWidget</name>
    <message>
        <location filename="src/NewScreenWidget.cpp" line="32"/>
        <source>Unnamed</source>
        <translation type="finished">Без назви</translation>
    </message>
</context>
<context>
    <name>PluginManager</name>
    <message>
        <location filename="src/PluginManager.cpp" line="58"/>
        <source>Failed to get plugin directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="63"/>
        <source>Failed to get profile directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="136"/>
        <source>Failed to download plugin '%1' to: %2
%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="167"/>
        <source>Could not get Windows architecture type.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="191"/>
        <source>Could not get Linux architecture type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginWizardPage</name>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="14"/>
        <source>Setup Barrier</source>
        <translation type="finished">Встановлення Barrier</translation>
    </message>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="101"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="72"/>
        <source>Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="80"/>
        <location filename="src/PluginWizardPage.cpp" line="201"/>
        <source>Setup complete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="93"/>
        <source>Downloading '%1' plugin (%2/%3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="104"/>
        <source>Plugins installed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="120"/>
        <source>Generating SSL certificate...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="170"/>
        <source>Downloading plugin: %1 (1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="239"/>
        <source>Getting plugin list...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>All files (*.*)</source>
        <translation type="finished">Всі файли (*.*)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>Barrier Configurations (*.sgc)</source>
        <translation type="finished">Конфігурація Barrier (*.sgc)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="67"/>
        <source>Barrier Configurations (*.conf)</source>
        <translation type="finished">Конфігурація Barrier (*.conf)</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="119"/>
        <source>System tray is unavailable, quitting.</source>
        <translation type="finished">Системний трей недоступний, здійснюється вихід.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialog</name>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
        <source>Screen name is empty</source>
        <translation type="finished">Ім'я екрану порожнє</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
        <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
        <translation type="finished">Ім'я екрану не може бути порожнім. Будь ласка вкажіть ім'я або скасуйте діалог.</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
        <source>Screen name matches alias</source>
        <translation type="finished">Ім'я екрану співпадає з псевдонімом</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
        <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
        <translation type="finished">Ім'я екрану не може бути таким самим як псевдонім. Будь ласка видаліть псевдонім або змініть ім'я екрану</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialogBase</name>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="14"/>
        <source>Screen Settings</source>
        <translation type="finished">Налаштування екрану</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="22"/>
        <source>Screen &amp;name:</source>
        <translation type="finished">Ім'я екрану:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="42"/>
        <source>A&amp;liases</source>
        <translation type="finished">Псевдоніми</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="57"/>
        <source>&amp;Add</source>
        <translation type="finished">Додати</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="74"/>
        <source>&amp;Remove</source>
        <translation type="finished">Видалити</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="97"/>
        <source>&amp;Modifier keys</source>
        <translation type="finished">Клавіші-модифікатори</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="106"/>
        <source>&amp;Shift:</source>
        <translation type="finished">Shift:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="117"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="164"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="211"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="258"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="305"/>
        <source>Shift</source>
        <translation type="finished">Shift</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="122"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="169"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="216"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="263"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="310"/>
        <source>Ctrl</source>
        <translation type="finished">Ctrl</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="127"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="174"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="221"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="268"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="315"/>
        <source>Alt</source>
        <translation type="finished">Alt</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="132"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="179"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="226"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="273"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="320"/>
        <source>Meta</source>
        <translation type="finished">Meta</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="137"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="184"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="231"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="278"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="325"/>
        <source>Super</source>
        <translation type="finished">Super</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="142"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="189"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="236"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="283"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="330"/>
        <source>None</source>
        <translation type="finished">Жодна</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="150"/>
        <source>&amp;Ctrl:</source>
        <translation type="finished">Ctrl:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="197"/>
        <source>Al&amp;t:</source>
        <translation type="finished">Alt:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="244"/>
        <source>M&amp;eta:</source>
        <translation type="finished">Meta:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="291"/>
        <source>S&amp;uper:</source>
        <translation type="finished">Super:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="358"/>
        <source>&amp;Dead corners</source>
        <translation type="finished">Мертві кути</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="367"/>
        <source>Top-left</source>
        <translation type="finished">Верхній лівий</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="374"/>
        <source>Top-right</source>
        <translation type="finished">Верхній правий</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="381"/>
        <source>Bottom-left</source>
        <translation type="finished">Нижній лівий</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="388"/>
        <source>Bottom-right</source>
        <translation type="finished">Нижній правий</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="397"/>
        <source>Corner Si&amp;ze:</source>
        <translation type="finished">Розмір кута:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="428"/>
        <source>&amp;Fixes</source>
        <translation type="finished">Фіксація</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="437"/>
        <source>Fix CAPS LOCK key</source>
        <translation type="finished">Фіксувати CAPS LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="444"/>
        <source>Fix NUM LOCK key</source>
        <translation type="finished">Фіксувати NUM LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="451"/>
        <source>Fix SCROLL LOCK key</source>
        <translation type="finished">Фіксувати SCROLL LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="458"/>
        <source>Fix XTest for Xinerama</source>
        <translation type="finished">Фіксувати XTest для Xinerama</translation>
    </message>
</context>
<context>
    <name>ScreenSetupModel</name>
    <message>
        <location filename="src/ScreenSetupModel.cpp" line="51"/>
        <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
        <translation type="finished">&lt;center&gt;Екран: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Подвійний клік для редагування налаштувань&lt;br&gt;Перетягніть екран у кошик для видалення</translation>
    </message>
</context>
<context>
    <name>ServerConfigDialog</name>
    <message>
        <location filename="src/ServerConfigDialog.cpp" line="75"/>
        <source>Configure server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerConfigDialogBase</name>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="14"/>
        <source>Server Configuration</source>
        <translation type="finished">Конфігурація сервера</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="24"/>
        <source>Screens and links</source>
        <translation type="finished">Екрани і зв'язки</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="35"/>
        <source>Drag a screen from the grid to the trashcan to remove it.</source>
        <translation type="finished">Перетягніть екран у кошик для видалення</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="60"/>
        <source>Configure the layout of your barrier server configuration.</source>
        <translation type="finished">Налаштувати розташування конфігурації сервера Barrier .</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="73"/>
        <source>Drag this button to the grid to add a new screen.</source>
        <translation type="finished">Перетягніть цю кнопку на сітку, щоб додати новий екран.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="128"/>
        <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
        <translation type="finished">Перетягуйте нові екрани на сітку або пересувайте існуючі місцями.
Перетягніть екран в кошик, щоб видалити його.
Подвійний клік на екрані для його налаштування.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="157"/>
        <source>Hotkeys</source>
        <translation type="finished">Гарячі клавіші</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="163"/>
        <source>&amp;Hotkeys</source>
        <translation type="finished">Гарячі клавіші</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="175"/>
        <source>&amp;New</source>
        <translation type="finished">Новий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation type="finished">Редагування</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="195"/>
        <source>&amp;Remove</source>
        <translation type="finished">Видалити</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="218"/>
        <source>A&amp;ctions</source>
        <translation type="finished">Дії</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="230"/>
        <source>Ne&amp;w</source>
        <translation type="finished">Новий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="240"/>
        <source>E&amp;dit</source>
        <translation type="finished">Редагувати</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="250"/>
        <source>Re&amp;move</source>
        <translation type="finished">Видалити</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="274"/>
        <source>Advanced server settings</source>
        <translation type="finished">Додаткові налаштування сервера</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="280"/>
        <source>&amp;Switch</source>
        <translation type="finished">Перехід</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="291"/>
        <source>Switch &amp;after waiting</source>
        <translation type="finished">Перехід після очікування</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="330"/>
        <location filename="res/ServerConfigDialogBase.ui" line="383"/>
        <location filename="res/ServerConfigDialogBase.ui" line="458"/>
        <source>ms</source>
        <translation type="finished">мсек</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="344"/>
        <source>Switch on double &amp;tap within</source>
        <translation type="finished">Перехід після подвійного натискання протягом</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="408"/>
        <source>&amp;Options</source>
        <translation type="finished">Опції</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="419"/>
        <source>&amp;Check clients every</source>
        <translation type="finished">Перевіряти клієнтів кожні</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="470"/>
        <source>Use &amp;relative mouse moves</source>
        <translation type="finished">Використовувати рідні налаштування курсору</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="480"/>
        <source>S&amp;ynchronize screen savers</source>
        <translation type="finished">Синхронізувати заставки</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="490"/>
        <source>Don't take &amp;foreground window on Windows servers</source>
        <translation type="finished">Не залишати вікно сервера зверху (у Windows)</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="510"/>
        <source>Ignore auto config clients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="520"/>
        <source>&amp;Dead corners</source>
        <translation type="finished">Мертві кути</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="529"/>
        <source>To&amp;p-left</source>
        <translation type="finished">Верхній лівий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="536"/>
        <source>Top-rig&amp;ht</source>
        <translation type="finished">Верхній правий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="543"/>
        <source>&amp;Bottom-left</source>
        <translation type="finished">Нижній лівий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="550"/>
        <source>Bottom-ri&amp;ght</source>
        <translation type="finished">Нижній правий</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="572"/>
        <source>Cor&amp;ner Size:</source>
        <translation type="finished">Розмір кута:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/SettingsDialog.cpp" line="131"/>
        <source>Save log file to...</source>
        <translation type="finished">Зберегти log-файл в...</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="151"/>
        <source>Elevate Barrier</source>
        <translation type="finished">Підвищіть рівень доступу Barrier</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="152"/>
        <source>Are you sure you want to elevate Barrier?

This allows Barrier to interact with elevated processes and the UAC dialog, but can cause problems with non-elevated processes. Elevate Barrier only if you really need to.</source>
        <translation type="finished">Дійсно бажаєте підвищить рівень доступу Barrier?
Ця дія дозволить Barrier бути у взаємодії з процесами, які мають підвищеній рівень доступу, та діалогу UAC (контроль облікових записів користувачів). Але це може викликати проблеми з процесами, які мають звичайний рівень доступу. Підвищуйте рівень доступу Barrier тільки в тому випадку, коли це дійсно потрібно.</translation>
    </message>
</context>
<context>
    <name>SettingsDialogBase</name>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="14"/>
        <source>Settings</source>
        <translation type="finished">Налаштування</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="32"/>
        <source>Sc&amp;reen name:</source>
        <translation type="finished">Ім'я екрану:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="49"/>
        <source>P&amp;ort:</source>
        <translation type="finished">Порт:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="78"/>
        <source>&amp;Interface:</source>
        <translation type="finished">Інтерфейс:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="120"/>
        <source>Elevate mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="127"/>
        <source>&amp;Hide on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="146"/>
        <source>&amp;Network Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="155"/>
        <source>Use &amp;SSL encryption (unique certificate)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="184"/>
        <source>Logging</source>
        <translation type="finished">Запис</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="202"/>
        <source>&amp;Logging level:</source>
        <translation type="finished">Рівень запису:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="251"/>
        <source>Log to file:</source>
        <translation type="finished">Записувати у фал:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="268"/>
        <source>Browse...</source>
        <translation type="finished">Перегляд...</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="213"/>
        <source>Error</source>
        <translation type="finished">Помилка</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="107"/>
        <source>&amp;Language:</source>
        <translation type="finished">Мова:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="20"/>
        <source>&amp;Miscellaneous</source>
        <translation type="finished">&amp;Додатково</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="218"/>
        <source>Warning</source>
        <translation type="finished">Попередження</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="223"/>
        <source>Note</source>
        <translation type="finished">Примітка</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="228"/>
        <source>Info</source>
        <translation type="finished">Інформація</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="233"/>
        <source>Debug</source>
        <translation type="finished">Налагодження</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="238"/>
        <source>Debug1</source>
        <translation type="finished">Налагодження1</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="243"/>
        <source>Debug2</source>
        <translation type="finished">Налагодження2</translation>
    </message>
</context>
<context>
    <name>SetupWizard</name>
    <message>
        <location filename="src/SetupWizard.cpp" line="72"/>
        <source>Setup Barrier</source>
        <translation type="finished">Встановлення Barrier</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="113"/>
        <source>Please select an option.</source>
        <translation type="finished">Будь ласка, оберіть опцію.</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="80"/>
        <source>Please enter your email address and password.</source>
        <translation type="finished">Будь ласка вкажіть адресу вашої електронної пошти та пароль.</translation>
    </message>
</context>
<context>
    <name>SetupWizardBase</name>
    <message>
        <location filename="res/SetupWizardBase.ui" line="26"/>
        <source>Setup Barrier</source>
        <translation type="finished">Встановлення Barrier</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="30"/>
        <source>Welcome</source>
        <translation type="finished">Вітаемо</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="39"/>
        <source>Thanks for installing Barrier!</source>
        <translation type="finished">Дякуємо за встановлення Barrier!</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="114"/>
        <source>Barrier lets you easily share your mouse and keyboard between multiple computers on your desk, and it's Free and Open Source. Just move your mouse off the edge of one computer's screen on to another. You can even share all of your clipboards. All you need is a network connection. Barrier is cross-platform (works on Windows, Mac OS X and Linux).</source>
        <translation type="finished">Barrier дозволить Вам легко використовувати мишку та клавіатуру між декількома комп'ютерами за вашим столом, і це зовсім безкоштовний та відкритий продукт. Тільки підведіть курсор мишки до краю одного з комп'ютерів і він автоматично переміститься на інший. Також можна використовувати один буфер обміну між декількома комп'ютерами. Все що необхідно, це мережеве з'єднання. Barrier являється міжплатформовим продуктом  (працює з Windows, Mac OS X та Linux).</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="125"/>
        <source>Activate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="131"/>
        <source>&amp;Activate now...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="152"/>
        <source>Email:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="178"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="204"/>
        <source>&lt;a href=&quot;https://symless.com/account/reset/&quot;&gt;Forgot password&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="232"/>
        <source>&amp;Skip activation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="277"/>
        <source>&amp;Server (share this computer's mouse and keyboard)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="290"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer's screen. There can only be one server in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="326"/>
        <source>&amp;Client (use another computer's mouse and keyboard)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="339"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;You have already set up a server. This computer will be controlled using the server's mouse and keyboard. There can be many clients in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="262"/>
        <source>Server or Client?</source>
        <translation type="finished">Сервер чи клієнт?</translation>
    </message>
</context>
<context>
    <name>SslCertificate</name>
    <message>
        <location filename="src/SslCertificate.cpp" line="42"/>
        <source>Failed to get profile directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="141"/>
        <source>SSL certificate generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="170"/>
        <source>SSL fingerprint generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="173"/>
        <source>Failed to find SSL fingerprint.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionChecker</name>
    <message>
        <location filename="src/VersionChecker.cpp" line="102"/>
        <source>Unknown</source>
        <translation type="finished">Невідомо</translation>
    </message>
</context>
<context>
    <name>WebClient</name>
    <message>
        <location filename="src/WebClient.cpp" line="44"/>
        <source>An error occurred while trying to sign in. Please contact the helpdesk, and provide the following details.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="65"/>
        <source>Login failed, invalid email or password.</source>
        <translation type="finished">Вхід скасовано, неправильна адреса або пароль.</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="78"/>
        <source>Login failed, an error occurred.

%1</source>
        <translation type="finished">Вхід скасовано, виникла помилка.
%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="86"/>
        <source>Login failed, an error occurred.

Server response:

%1</source>
        <translation type="finished">Вхід скасовано, виникла помилка.
Відповідь сервера:
%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="101"/>
        <source>An error occurred while trying to query the plugin list. Please contact the help desk, and provide the following details.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="120"/>
        <source>Get plugin list failed, invalid user email or password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="131"/>
        <source>Get plugin list failed, an error occurred.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="137"/>
        <source>Get plugin list failed, an error occurred.

Server response:

%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZeroconfService</name>
    <message>
        <location filename="src/ZeroconfService.cpp" line="82"/>
        <source>zeroconf server detected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="91"/>
        <source>zeroconf client detected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="99"/>
        <location filename="src/ZeroconfService.cpp" line="130"/>
        <source>Zero configuration service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="100"/>
        <source>Error code: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="131"/>
        <source>Unable to start the zeroconf: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="140"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="141"/>
        <source>Failed to get local IP address. Please manually type in server address on your clients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="147"/>
        <location filename="src/ZeroconfService.cpp" line="154"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>